@@ -5,7 +5,7 @@ BASEPATH=/usr/share/sweethome3d
 JAVA_ARGS="-Djava.library.path=/usr/lib/jni \
  -Dcom.eteks.sweethome3d.applicationFolders=$HOME/.eteks/sweethome3d:/usr/share/sweethome3d \
  -Dcom.eteks.sweethome3d.j3d.checkOffScreenSupport=false \
- -Dsun.java2d.opengl=true"
+ -Dsun.java2d.opengl=true --add-exports java.desktop/sun.awt=ALL-UNNAMED"
 
 . /usr/lib/java-wrappers/java-wrappers.sh
 
